# fabricio
Fabric extensions

[![Build Status](https://travis-ci.org/renskiy/fabricio.svg?branch=master)](https://travis-ci.org/renskiy/fabricio)
[![Coverage Status](https://coveralls.io/repos/github/renskiy/fabricio/badge.svg?branch=master)](https://coveralls.io/github/renskiy/fabricio?branch=master)
